<?php
/*
Plugin Name: Gameplorer`s WPColorBox
Plugin URI: http://www.gameplorer.de/tools/wordpress-colorbox/
Description: Gameplorer`s WPColorBox automatically adds a ColorBox effect to all of your linked images. Gameplorer`s WPColorBox enqueues ColorBox script and style. This can be deactivated, if you prefer to embed the code in your existing files. 
Author: Gameplorer.de
Author URI: http://www.gameplorer.de
Tags: colorbox, jquery, wordpress, image, images, posts, links, lighbox, thickbox, box, effect
Version: 1.3
*/

if (!class_exists('GameplorersWPColorBox')):

	class GameplorersWPColorBox {
		
		private static $pluginUrl = null;
		private static $group = 'gpswpcolorbox';
		private static $page = 'gpswpcbPage';
		
		public function __construct() {
			self::$pluginUrl = WP_PLUGIN_URL . '/gameplorers-wpcolorbox';
			
			register_deactivation_hook(__FILE__, array(__CLASS__, 'onDeactivate'));

			if (!is_admin()):
				add_filter('the_content', array(__CLASS__, 'onTheContent'), 100);
				add_filter('the_excerpt', array(__CLASS__, 'onTheContent'), 100);
				add_action('after_setup_theme', array(__CLASS__, 'onAfterSetupTheme'));
			endif;
			
			add_action('admin_menu', array(__CLASS__, 'onAdminMenu'), 9);
			add_action('admin_init', array(__CLASS__, 'onAdminInit'), 9);
		}

		public function onAdminInit() {
			$options = self::getOptions();
			
			register_setting(self::$group, self::$group);
			
			$section = 'gpswpcbEnqueueSection';
			add_settings_section($section, 'Scripts &amp; Styles', create_function('', 'echo "<p>If you copy and paste the ColorBox script and style into your existing files, uncheck the following options:</p>";'), self::$page);
			add_settings_field('js', 'Include ColorBox-JavaScript', create_function('', __CLASS__ . '::printCheckbox("js", "' . $options['js'] . '");'), self::$page, $section);
			add_settings_field('css', 'Include ColorBox-Stylesheet', create_function('', __CLASS__ . '::printCheckbox("css", "' . $options['css'] . '");'), self::$page, $section);
			
			$section = 'gpswpcbVersionSection';
			add_settings_section($section, 'Version', create_function('', 'echo "";'), self::$page);
			add_settings_field('v', 'Version', create_function('', __CLASS__ . '::printVersionSelect("' . $options['v'] . '");'), self::$page, $section);
		}
		
		public function onAdminMenu() {
			add_options_page('GP`s WPColorBox', 'GP`s WPColorBox', 'manage_options', self::$page, create_function('', __CLASS__ . '::printAdminGui();'));
		}

		public function onTheContent($content) {

			// find links with images
			$matches = array();
			$pattern = '#(<a.+href=("|\').+\.(?:jpe?g|gif|png)\2[^>]*>)#Ui';
			if (!preg_match_all($pattern, $content, $matches, PREG_SET_ORDER)):
				return $content;
			endif;
			
			global $post;
			foreach ($matches as $m):
			
				$newLink = $m[1];
				if (preg_match('#nocolorbox#', $newLink)):
					continue;
				endif;
				
				// add class
				if (!preg_match('#class=#', $newLink)):
					$newLink = preg_replace('#>$#', ' class="colorbox">', $newLink);
				else:
					$newLink = preg_replace('#class=("|\')#i', 'class=$1colorbox ', $newLink);
				endif;
				
				// add rel
				if (!preg_match('#rel=#', $newLink)):
					$newLink = preg_replace('#<a([^>]*)>#', '<a$1 rel="colorbox-' . $post->ID . '">', $newLink);
				else:
					$newLink = preg_replace('#rel=("|\')#i', 'rel=$1colorbox-' . $post->ID . ' ', $newLink);
				endif;
				
				$content = str_replace($m[1], $newLink, $content);
				
			endforeach;

			return $content;
		}
		
		public function onAfterSetupTheme() {
			$options = self::getOptions();
			
			if ($options['js'] == '1')
				wp_enqueue_script('jquery.colorbox', self::$pluginUrl . '/colorbox/colorbox/jquery.colorbox-min.js', array('jquery'), '1.3.17', true);
			if ($options['css'] == '1')
				wp_enqueue_style('colorbox', self::$pluginUrl . '/colorbox/example' . $options['v'] . '/colorbox.css', null, '1.3.17');
		}
		
		public function onDeactivate() {   
			delete_option(self::$group);
		}
		
		public static function printAdminGui() {
			echo '<div id="icon-options-general" class="icon32"><br></div><div class="wrap">';
			echo '<h2>Gameplorer`s WPColorBox</h2>';
			echo '<p><em>Gameplorer`s WPColorBox</em> automatically adds a ColorBox effect to all of your linked images.<br/>';
			echo 'For further information visit the <a href="http://wordpress.org/extend/plugins/gameplorers-wpcolorbox/" target="_blank">plugin page on wordpress.org</a>.</p>';
			echo '<form action="options.php" method="post">';
			echo settings_fields(self::$group);
			echo do_settings_sections(self::$page);
			echo '<p class="submit"><input type="submit" class="button-primary" value="';
			_e('Save Changes');
			echo '"/></p></form>';
			
			echo '<h3>Help</h3>';
			echo '<ul><li>You want to customize your ColorBox settings? Have a look at the <a href="http://colorpowered.com/colorbox/" target="_blank">official ColorBox site</a>.</li>';
			echo '<li>You have questions or problems with ColorBox (JavaScript or CSS)? Visit the <a href="http://groups.google.com/group/colorbox/topics?pli=1" target="_blank">ColorBox Google Group</a>.</li>';
			echo '<li>You have questions or problems with the WordPress Plugin itself? Visit the <a href="http://www.gameplorer.de/tools/wordpress-colorbox/" target="_blank">Plugin site</a>.</li>';
			echo '</ul>';
			echo '<h3>Credits</h3>';
			echo '<p>The jQuery plugin <em>ColorBox</em> is developed by <a href="http://twitter.com/jacklmoore" target="_blank">@JacklMoore</a>.</p>';
			echo '<p>The WordPress plugin <em>Gameplorer`s WPColorBox</em> is developed by <a href="http://twitter.com/gameplorer" target="_blank">@Gameplorer</a>.</p>';
			
			echo '</div>';
		}
		
		public static function printCheckbox($name, $value) {
			echo '<input type="checkbox" name="' . self::$group . '[' . $name . ']" value="1"';
			if ($value == '1')
				echo ' checked="checked"';
			echo '"/>';
		}

		public static function printVersionSelect($value) {
			for ($i = 1; $i <= 5; ++$i):
				echo '<p><input type="radio" name="' . self::$group . '[v]" value="' . $i . '"';
				if ((int)$value == $i)
					echo ' checked="checked"';
				echo '/> <a href="' . self::$pluginUrl . '/colorbox/example' . $i . '/index.html" target="_blank">Version ' . $i . '</a></p>';
			endfor;
		}
		
		private static function getOptions() {
			$options = get_option(self::$group);
			
			// saved at least one time?
			if (isset($options['v']))
				return $options;

			// never clicked save. set initial values:
			if (!isset($options['js']))
				$options['js'] = '1';
			if (!isset($options['css']))
				$options['css'] = '1';
			if (!isset($options['v']))
				$options['v'] = '2';
				
			return $options;
		}
	}

	// init plugin
	new GameplorersWPColorBox();

endif;
?>